<?php
session_start();
include('db.php');

// Check if the user is logged in and is an admin
if (!isset($_SESSION['user'])) {
    header('Location: login.php');  // Redirect to login page if not logged in
    exit;
}

$user = $_SESSION['user'];  // Logged-in user
$is_admin = ($user['role'] == 'admin');  // Check if the logged-in user is an admin

$notifications = [];

// Handle assigning product to user and whitelist IP (only for admins)
if ($is_admin && isset($_POST['assign_product'])) {
    $assigned_user_id = $_POST['user_id'];  // User to whom the product will be assigned
    $product_id = $_POST['product_id'];  // Product ID to be assigned
    $ip_address = $_POST['ip_address'];  // IP address to whitelist for the user

    // Check if the user already has the product assigned
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM whitelist WHERE user_id = :user_id AND product_id = :product_id");
    $stmt->bindParam(':user_id', $assigned_user_id);
    $stmt->bindParam(':product_id', $product_id);
    $stmt->execute();
    $count = $stmt->fetchColumn();

    if ($count == 0) {
        // Add to whitelist if the user does not already have the product
        $stmt = $pdo->prepare("INSERT INTO whitelist (user_id, product_id, ip_address) VALUES (:user_id, :product_id, :ip_address)");
        $stmt->bindParam(':user_id', $assigned_user_id);
        $stmt->bindParam(':product_id', $product_id);
        $stmt->bindParam(':ip_address', $ip_address);
        if ($stmt->execute()) {
            $notifications[] = 'Product assigned and IP added to whitelist successfully.';
        } else {
            $notifications[] = 'Failed to assign product or add IP to whitelist.';
        }
    } else {
        $notifications[] = 'This product is already assigned to this user.';
    }
}

// Handle removing product from user (only for admins)
if ($is_admin && isset($_POST['remove_product'])) {
    $assigned_user_id = $_POST['user_id'];  // User from whom the product will be removed
    $product_id = $_POST['product_id'];  // Product ID to be removed

    // Remove the product from the user
    $stmt = $pdo->prepare("DELETE FROM whitelist WHERE user_id = :user_id AND product_id = :product_id");
    $stmt->bindParam(':user_id', $assigned_user_id);
    $stmt->bindParam(':product_id', $product_id);
    if ($stmt->execute()) {
        $notifications[] = 'Product removed from user successfully.';
    } else {
        $notifications[] = 'Failed to remove product from user.';
    }
}

// Fetch all products
$products = $pdo->query("SELECT * FROM products")->fetchAll();

// Fetch all users (only for admins)
if ($is_admin) {
    $users = $pdo->query("SELECT * FROM users")->fetchAll();
}

// Fetch the products assigned to a specific user (for admin removal section)
if ($is_admin && isset($_POST['remove_user_id'])) {
    $stmt = $pdo->prepare("SELECT p.id, p.name, p.description, p.file_path
                           FROM products p
                           JOIN whitelist w ON p.id = w.product_id
                           WHERE w.user_id = :user_id");
    $stmt->bindParam(':user_id', $_POST['remove_user_id']);
    $stmt->execute();
    $user_assigned_products = $stmt->fetchAll();
}

// Fetch all users and their assigned products (for admin view section)
if ($is_admin) {
    $stmt = $pdo->query("SELECT u.id, u.username, p.id AS product_id, p.name AS product_name
                         FROM users u
                         LEFT JOIN whitelist w ON u.id = w.user_id
                         LEFT JOIN products p ON w.product_id = p.id");
    $user_product_data = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch the products assigned to the logged-in user
$stmt = $pdo->prepare("SELECT p.id, p.name, p.description, p.file_path
                       FROM products p
                       JOIN whitelist w ON p.id = w.product_id
                       WHERE w.user_id = :user_id");
$stmt->bindParam(':user_id', $user['id']);
$stmt->execute();
$assigned_products = $stmt->fetchAll();
