<?php
session_start();
include('db.php');

// Check if the user is logged in and is an admin
if (!isset($_SESSION['user'])) {
    header('Location: login.php');  // Redirect to login page if not logged in
    exit;
}

$user = $_SESSION['user'];  // Logged-in user
$is_admin = ($user['role'] == 'admin');  // Check if the logged-in user is an admin

// Logout functionality
if (isset($_POST['logout'])) {
    session_destroy();  // Destroy the session
    header('Location: login.php');  // Redirect to the login page after logging out
    exit;
}

// Handle assigning product to user and whitelist IP (only for admins)
if ($is_admin && isset($_POST['assign_product'])) {
    $assigned_user_id = $_POST['user_id'];  // User to whom the product will be assigned
    $product_id = $_POST['product_id'];  // Product ID to be assigned
    $ip_address = $_POST['ip_address'];  // IP address to whitelist for the user

    // Check if the user already has the product assigned
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM whitelist WHERE user_id = :user_id AND product_id = :product_id");
    $stmt->bindParam(':user_id', $assigned_user_id);
    $stmt->bindParam(':product_id', $product_id);
    $stmt->execute();
    $count = $stmt->fetchColumn();

    if ($count == 0) {
        // Add to whitelist if the user does not already have the product
        $stmt = $pdo->prepare("INSERT INTO whitelist (user_id, product_id, ip_address) VALUES (:user_id, :product_id, :ip_address)");
        $stmt->bindParam(':user_id', $assigned_user_id);
        $stmt->bindParam(':product_id', $product_id);
        $stmt->bindParam(':ip_address', $ip_address);
        if ($stmt->execute()) {
            $notifications[] = 'Product assigned and IP added to whitelist successfully.';
        } else {
            $notifications[] = 'Failed to assign product or add IP to whitelist.';
        }
    } else {
        $notifications[] = 'This product is already assigned to this user.';
    }
}

// Handle removing product from user (only for admins)
if ($is_admin && isset($_POST['remove_product'])) {
    $assigned_user_id = $_POST['user_id'];  // User from whom the product will be removed
    $product_id = $_POST['product_id'];  // Product ID to be removed

    // Remove the product from the user
    $stmt = $pdo->prepare("DELETE FROM whitelist WHERE user_id = :user_id AND product_id = :product_id");
    $stmt->bindParam(':user_id', $assigned_user_id);
    $stmt->bindParam(':product_id', $product_id);
    if ($stmt->execute()) {
        $notifications[] = 'Product removed from user successfully.';
    } else {
        $notifications[] = 'Failed to remove product from user.';
    }
}

// Handle File Create and File Update actions
if ($is_admin && isset($_POST['create_file'])) {
    $product_id = $_POST['product_id'];  // Product ID for which to create a file
    $file_path = $_POST['file_path'];  // Path for the new file

    // Create a new file for the product
    $stmt = $pdo->prepare("UPDATE products SET file_path = :file_path WHERE id = :product_id");
    $stmt->bindParam(':file_path', $file_path);
    $stmt->bindParam(':product_id', $product_id);
    if ($stmt->execute()) {
        $notifications[] = 'File created successfully for the product.';
    } else {
        $notifications[] = 'Failed to create file for the product.';
    }
}

if ($is_admin && isset($_POST['update_file'])) {
    $product_id = $_POST['product_id'];  // Product ID for which to update the file
    $file_path = $_POST['file_path'];  // New file path

    // Update the file for the product
    $stmt = $pdo->prepare("UPDATE products SET file_path = :file_path WHERE id = :product_id");
    $stmt->bindParam(':file_path', $file_path);
    $stmt->bindParam(':product_id', $product_id);
    if ($stmt->execute()) {
        $notifications[] = 'File updated successfully for the product.';
    } else {
        $notifications[] = 'Failed to update file for the product.';
    }
}

// Fetch all products
$products = $pdo->query("SELECT * FROM products")->fetchAll();

// Fetch all users (only for admins)
if ($is_admin) {
    $users = $pdo->query("SELECT * FROM users")->fetchAll();
}

// Fetch all users and their assigned products (for admin view section)
if ($is_admin) {
    $stmt = $pdo->query("SELECT u.id, u.username, p.id AS product_id, p.name AS product_name
                         FROM users u
                         LEFT JOIN whitelist w ON u.id = w.user_id
                         LEFT JOIN products p ON w.product_id = p.id");
    $user_product_data = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch the products assigned to the logged-in user
$stmt = $pdo->prepare("SELECT p.id, p.name, p.description, p.file_path
                       FROM products p
                       JOIN whitelist w ON p.id = w.product_id
                       WHERE w.user_id = :user_id");
$stmt->bindParam(':user_id', $user['id']);
$stmt->execute();
$assigned_products = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FiveM IP Whitelist Panel - Royal Development</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
<style>
    body {
        font-family: 'Roboto', sans-serif;
        background: linear-gradient(135deg, #6e7dff, #3c5bdb);
        color: #fff;
        padding: 50px 0;
    }
    .container {
        max-width: 1200px;
        margin: 0 auto;
    }
    .card {
        border-radius: 15px;
        box-shadow: 0 4px 10px rgba(0, 0, 0, 0.2);
        margin-bottom: 30px;
    }
    .form-label {
        font-weight: 500;
    }
    .notification-bar {
        position: fixed;
        top: 0;
        right: 0;
        background-color: #28a745;
        color: white;
        padding: 10px;
        display: none;
        border-radius: 5px;
        z-index: 999;
    }
    .table th, .table td {
        vertical-align: middle;
    }
    .page-header {
        background-color: rgba(0, 0, 0, 0.6);
        padding: 20px 0;
        text-align: center;
        color: white;
        margin-bottom: 50px;
    }
    .page-header h1 {
        font-size: 2.5rem;
    }
    .royal-logo {
        font-size: 1.5rem;
        font-weight: 700;
        color: #FFD700; /* Royal Gold */
    }
    .user-product-list {
        margin-top: 30px;
    }
    .product-item {
        background-color: rgba(255, 255, 255, 0.1);
        padding: 15px;
        margin-bottom: 10px;
        border-radius: 10px;
    }
        /* New style to make the product section text black */
    .user-product-list h5, .user-product-list p {
        color: black;  /* Change the text color to black */
    }
    .logout-btn {
        position: fixed;
        top: 15px;
        right: 15px;
        background-color: #FF5733;
        color: white;
        border: none;
        padding: 10px 20px;
        border-radius: 5px;
        font-size: 1rem;
        cursor: pointer;
    }
    .logout-btn:hover {
        background-color: #C70039;
    }
</style>
</head>
<body>
    <div class="container">
        <div class="notification-bar" id="notification-bar">
            Product assigned or updated successfully.
        </div>

        <!-- Page Header with Royal Development Branding -->
        <div class="page-header">
            <h1>Welcome to the FiveM IP Whitelist Panel</h1>
            <p class="royal-logo">Powered by Royal Development</p>
        </div>

        <!-- Admin Features -->
        <?php if ($is_admin): ?>

            <!-- Assign Product to User and Whitelist IP -->
            <div class="card">
                <div class="card-body">
                    <h4 class="card-title text-center">Assign Product to User & Whitelist IP</h4>
                    <form method="POST">
                        <div class="mb-3">
                            <label for="user_id" class="form-label">Select User</label>
                            <select class="form-control" id="user_id" name="user_id" required>
                                <?php foreach ($users as $u): ?>
                                    <option value="<?php echo $u['id']; ?>"><?php echo $u['username']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="product_id" class="form-label">Select Product</label>
                            <select class="form-control" id="product_id" name="product_id" required>
                                <?php foreach ($products as $p): ?>
                                    <option value="<?php echo $p['id']; ?>"><?php echo $p['name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="ip_address" class="form-label">User IP Address</label>
                            <input type="text" class="form-control" id="ip_address" name="ip_address" required>
                        </div>
                        <button type="submit" name="assign_product" class="btn btn-primary w-100">Assign Product & Whitelist IP</button>
                    </form>
                </div>
            </div>

            <!-- Remove Product from User (Dropdown) -->
            <div class="card">
                <div class="card-body">
                    <h4 class="card-title text-center">Remove Product from User</h4>
                    <form method="POST">
                        <div class="mb-3">
                            <label for="user_id" class="form-label">Select User</label>
                            <select class="form-control" id="user_id" name="user_id" required>
                                <?php foreach ($users as $u): ?>
                                    <option value="<?php echo $u['id']; ?>"><?php echo $u['username']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="product_id" class="form-label">Select Product to Remove</label>
                            <select class="form-control" id="product_id" name="product_id" required>
                                <?php foreach ($products as $p): ?>
                                    <option value="<?php echo $p['id']; ?>"><?php echo $p['name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <button type="submit" name="remove_product" class="btn btn-danger w-100">Remove Product</button>
                    </form>
                </div>
            </div>

            <!-- File Create Section -->
            <div class="card">
                <div class="card-body">
                    <h4 class="card-title text-center">Create File for Product</h4>
                    <form method="POST">
                        <div class="mb-3">
                            <label for="product_id" class="form-label">Select Product</label>
                            <select class="form-control" id="product_id" name="product_id" required>
                                <?php foreach ($products as $p): ?>
                                    <option value="<?php echo $p['id']; ?>"><?php echo $p['name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="file_path" class="form-label">File Path</label>
                            <input type="text" class="form-control" id="file_path" name="file_path" required>
                        </div>
                        <button type="submit" name="create_file" class="btn btn-success w-100">Create File</button>
                    </form>
                </div>
            </div>

            <!-- File Update Section -->
            <div class="card">
                <div class="card-body">
                    <h4 class="card-title text-center">Update File for Product</h4>
                    <form method="POST">
                        <div class="mb-3">
                            <label for="product_id" class="form-label">Select Product</label>
                            <select class="form-control" id="product_id" name="product_id" required>
                                <?php foreach ($products as $p): ?>
                                    <option value="<?php echo $p['id']; ?>"><?php echo $p['name']; ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="file_path" class="form-label">New File Path</label>
                            <input type="text" class="form-control" id="file_path" name="file_path" required>
                        </div>
                        <button type="submit" name="update_file" class="btn btn-warning w-100">Update File</button>
                    </form>
                </div>
            </div>

        <?php endif; ?>

<!-- User's Assigned Products -->
<?php if (!$is_admin): ?>
    <div class="card">
        <div class="card-body">
            <h4 class="card-title text-center" style="color: black;">Your Assigned Products</h4>
            <div class="user-product-list">
                <?php if (count($assigned_products) > 0): ?>
                    <?php foreach ($assigned_products as $product): ?>
                        <div class="product-item">
                            <h5 style="color: black;"><?php echo $product['name']; ?></h5>
                            <p style="color: black;"><?php echo $product['description']; ?></p>
                            <a href="<?php echo $product['file_path']; ?>" download class="btn btn-info btn-sm">Download</a>
                        </div>
                    <?php endforeach; ?>
                <?php else: ?>
                    <p style="color: black;">No products assigned yet.</p>
                <?php endif; ?>
            </div>
        </div>
    </div>
<?php endif; ?>
</div>


    <!-- Logout Button -->
    <form method="POST">
        <button type="submit" name="logout" class="logout-btn">Logout</button>
    </form>

    <script>
        // Display notification bar when a product is added or updated
        function showNotification(message) {
            var notificationBar = document.getElementById("notification-bar");
            notificationBar.textContent = message;
            notificationBar.style.display = "block";
            setTimeout(function() {
                notificationBar.style.display = "none";
            }, 5000);
        }
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
