<?php
session_start();
include('db.php');

// Check if the user is already logged in
if (isset($_SESSION['user'])) {
    header('Location: index.php');  // Redirect to index page if already logged in
    exit;
}

if (isset($_POST['submit_register'])) {
    // Get form data
    $username = $_POST['username'];
    $password = $_POST['password'];

    // Basic validation
    if (empty($username) || empty($password)) {
        echo "<script>alert('Username and password are required.');</script>";
    } else {
        // Hash the password using bcrypt
        $hashed_password = password_hash($password, PASSWORD_BCRYPT);

        // Automatically assign the "user" role (no need for role input field)
        $role = 'user';

        // Check if the username already exists
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM users WHERE username = :username");
        $stmt->bindParam(':username', $username);
        $stmt->execute();
        $user_count = $stmt->fetchColumn();

        if ($user_count > 0) {
            echo "<script>alert('Username already exists. Please choose a different username.');</script>";
        } else {
            // Insert the new user into the database
            $stmt = $pdo->prepare("INSERT INTO users (username, password, role) VALUES (:username, :password, :role)");
            $stmt->bindParam(':username', $username);
            $stmt->bindParam(':password', $hashed_password);
            $stmt->bindParam(':role', $role);

            if ($stmt->execute()) {
                echo "<script>alert('Registration successful! Please login.'); window.location.href = 'login.php';</script>";
            } else {
                echo "<script>alert('Registration failed. Please try again.');</script>";
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Register - FiveM IP Whitelist System</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Roboto', sans-serif;
            background: linear-gradient(135deg, #6e7dff, #3c5bdb);
            color: #fff;
            padding: 50px 0;
        }

        .container {
            max-width: 500px;
            margin: 0 auto;
            padding: 30px;
            background-color: #2b3b66;
            border-radius: 10px;
        }

        .form-control {
            border-radius: 30px;
            padding: 10px;
        }

        .btn {
            border-radius: 30px;
            transition: background-color 0.3s ease;
        }

        .btn:hover {
            background-color: #ff5e5b;
        }

        .form-title {
            text-align: center;
            font-size: 24px;
            margin-bottom: 20px;
        }

        .form-label {
            font-weight: 500;
        }
    </style>
</head>
<body>

    <div class="container">
        <h2 class="form-title">Register</h2>

        <form method="POST" action="register.php">
            <div class="mb-3">
                <label for="username" class="form-label">Username</label>
                <input type="text" class="form-control" id="username" name="username" required>
            </div>

            <div class="mb-3">
                <label for="password" class="form-label">Password</label>
                <input type="password" class="form-control" id="password" name="password" required>
            </div>

            <button type="submit" name="submit_register" class="btn btn-primary w-100">Register</button>
        </form>

        <p class="mt-3 text-center">Already have an account? <a href="login.php" class="text-light">Login here</a></p>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
